==> gbsite-1.1.0.tar.gz: gbsite/templates/master/master_buglistpage.php <==
<table cellpadding="2" cellspacing="0" border="0" width="100%">
<tr>
<td colspan="4"><img src="<?= $image_path ?>/proj_spacer.gif" width="42" height="15"><font face="<?= $font_1 ?>" size="2" color="<?= $color_6?>"><b>The <?= $project_name ?> Project</b></font></td>
</tr>
<? if (!empty($success)) { ?>
<tr>
<td colspan="4"><font face=<?= $font_1 ?> size="2" color="<?= $color_3 ?>">Your bug has been added.</font><br><br></td>
</tr>
<? } ?>
<tr>
</tr>
<!--- show status stuff --->
<tr>
<form method="post" action="/project/<?= $project_name ?>/bugs/buglist.php">
<td colspan="4" align="right"><font face="<?= $font_1 ?>" size="2">Show:</font> <select name="showtype[]">
                 <option value="">All</option>
<? while(list($id,$name) = @each($statusList)) { ?>
                 <option value="<?= $id ?>"><?= $name ?></option>
<? } ?>
                 </select> <input type="submit" value="Go"></td>
</tr>
</form>
<!--- end the show status stuff --->
<? if($num_bugs!=0){ ?>
<tr>
<td colspan="4"><font face="<?= $font_1 ?>" size="2"><b>There are <?= $num_bugs ?> bugs reported for this project. <a href="/project/<?= $project_name ?>/bugs/bugadd.php">Click here to add a bug</a>.</font></td>
</tr>
<tr bgcolor="<?= $color_4 ?>">
<td><font face="<?= $font_1 ?>" size="2"><b>Summary</b></font></td>
<td><font face="<?= $font_1 ?>" size="2"><b>Status</b></font></td>
<td><font face="<?= $font_1 ?>" size="2"><b>Severity</b></font></td>
<td><font face="<?= $font_1 ?>" size="2"><b>Created</b></font></td>
</tr>
<? while(list(,$currbug) = @each($bug_list)) { 
	if ($row_bgcolor == $color_2){
		$row_bgcolor = $color_7;
		}
		else {
		$row_bgcolor = $color_2; }
?>
<tr bgcolor="<?= $bgcolor ?>">
<td><font face="<?= $font_1 ?>" size="2"><a href="/project/<?= $project_name ?>/bugs/bugupdate.php?<?= $currbug["bug_id"] ?>"><?= $currbug["title"] ?></a></font></td>
<td><font face="<?= $font_1 ?>" size="2"><?= $currbug["cat_name"] ?></font></td>
<td><font face="<?= $font_1 ?>" size="2"><?= $currbug["severity"] ?></font></td>
<td><font face="<?= $font_1 ?>" size="2"><?= date("m/d/Y",strtotime($currbug["date_created"])) ?></font></td>
</tr>
<? } ?>
<? } else { ?>
<tr>
<td colspan="4"><br><br><font face="<?= $font_1 ?>" size="2"><b>There have not been any bugs reported for this project. <a href="/project/<?= $project_name ?>/bugs/bugadd.php">Click here to add a bug</a>.</b></font></td>
</tr>
<? } ?>
</table>

==> gbsite-1.1.1.tar.gz: gbsite/templates/master/master_buglistpage.php <==
<table cellpadding="4" cellspacing="0" border="0" width="100%">
<tr>
<td colspan="4"><img src="<?= $image_path ?>/proj_spacer.gif" width="42" height="15"><font face="<?= $font_1 ?>" size="2" color="<?= $color_6?>"><b>The <?= $project_name ?> Project</b></font></td>
</tr>
<? if (!empty($success)) { ?>
<tr>
<td colspan="4"><font face=<?= $font_1 ?> size="2" color="<?= $color_3 ?>">Your bug has been added.</font><br><br></td>
</tr>
<? } ?>
<tr>
</tr>
<!--- show status stuff --->
<tr>
<form method="post" action="/project/<?= $project_name ?>/bugs/buglist.php">
<td colspan="4" align="right"><font face="<?= $font_1 ?>" size="2">Show:</font> <select name="showtype[]">
                 <option value="">All</option>
<? while(list($id,$name) = @each($statusList)) { ?>
                 <option value="<?= $id ?>"><?= $name ?></option>
<? } ?>
                 <option value="!Closed">Not Closed</option>
                 </select> <input type="submit" value="Go"></td>
</tr>
</form>
<!--- end the show status stuff --->
<? if($num_bugs!=0){ ?>
<tr>
<td colspan="4"><font face="<?= $font_1 ?>" size="2"><b>There are <?= $num_bugs ?> bugs reported for this project. <a href="/project/<?= $project_name ?>/bugs/bugadd.php">Click here to add a bug</a>.</font></td>
</tr>
<tr bgcolor="<?= $color_4 ?>">
<td><font face="<?= $font_1 ?>" size="2"><b>Summary</b></font></td>
<td><font face="<?= $font_1 ?>" size="2"><b>Status</b></font></td>
<td><font face="<?= $font_1 ?>" size="2"><b>Severity</b></font></td>
<td><font face="<?= $font_1 ?>" size="2"><b>Created</b></font></td>
</tr>
<? while(list(,$currbug) = @each($bug_list)) { 
	if ($row_bgcolor == $color_2){
		$row_bgcolor = $color_7;
		}
		else {
		$row_bgcolor = $color_2; }
?>
<tr bgcolor="<?= $row_bgcolor ?>">
<td><font face="<?= $font_1 ?>" size="2"><a href="/project/<?= $project_name ?>/bugs/bugupdate.php?<?= $currbug["bug_id"] ?>"><?= $currbug["title"] ?></a><?= ($currbug["comment_count"]<1?"":" (".$currbug["comment_count"]." comments)") ?></font></td>
<td><font face="<?= $font_1 ?>" size="2"><?= $currbug["cat_name"] ?></font></td>
<td><font face="<?= $font_1 ?>" size="2"><?= $currbug["severity"] ?></font></td>
<td><font face="<?= $font_1 ?>" size="2"><?= date("m/d/Y",strtotime($currbug["date_created"])) ?></font></td>
</tr>
<? } ?>
<? } else { ?>
<tr>
<td colspan="4"><br><br><font face="<?= $font_1 ?>" size="2"><b>There have not been any bugs reported for this project. <a href="/project/<?= $project_name ?>/bugs/bugadd.php">Click here to add a bug</a>.</b></font></td>
</tr>
<? } ?>
</table>
